@@ -30,7 +30,7 @@ Here is a minimal deployable pattern definition:
 
 Typescript
 
-```python
+```typescript
 import { Construct } from 'constructs';
 import { Stack, StackProps } from 'aws-cdk-lib';
 import { FargateToEventbridge, FargateToEventbridgeProps } from '@aws-solutions-constructs/aws-fargate-eventbridge';
@@ -144,40 +144,38 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_ec2
 import aws_cdk.aws_ecs
 import aws_cdk.aws_events
-import aws_cdk.core
+import constructs
 
 
 class FargateToEventbridge(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-fargate-eventbridge.FargateToEventbridge",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         public_api: builtins.bool,
-        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+        cluster_props: typing.Optional[aws_cdk.aws_ecs.ClusterProps] = None,
         container_definition_props: typing.Any = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
         event_bus_environment_variable_name: typing.Optional[builtins.str] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
         existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         fargate_service_props: typing.Any = None,
         fargate_task_definition_props: typing.Any = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
         :param scope: -
@@ -197,30 +195,6 @@ class FargateToEventbridge(
         :param fargate_task_definition_props: -
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. A Step Functions Interface endpoint will be included in this VPC. Default: - A set of defaults from vpc-defaults.ts: DefaultPublicPrivateVpcProps() for public APIs and DefaultIsolatedVpcProps() for private APIs.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                public_api: builtins.bool,
-                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
-                container_definition_props: typing.Any = None,
-                ecr_image_version: typing.Optional[builtins.str] = None,
-                ecr_repository_arn: typing.Optional[builtins.str] = None,
-                event_bus_environment_variable_name: typing.Optional[builtins.str] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                fargate_service_props: typing.Any = None,
-                fargate_task_definition_props: typing.Any = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = FargateToEventbridgeProps(
             public_api=public_api,
             cluster_props=cluster_props,
@@ -240,22 +214,22 @@ class FargateToEventbridge(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="container")
     def container(self) -> aws_cdk.aws_ecs.ContainerDefinition:
         return typing.cast(aws_cdk.aws_ecs.ContainerDefinition, jsii.get(self, "container"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="service")
     def service(self) -> aws_cdk.aws_ecs.FargateService:
         return typing.cast(aws_cdk.aws_ecs.FargateService, jsii.get(self, "service"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
         return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="eventBus")
     def event_bus(self) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
         return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], jsii.get(self, "eventBus"))
@@ -286,19 +260,19 @@ class FargateToEventbridgeProps:
         self,
         *,
         public_api: builtins.bool,
-        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+        cluster_props: typing.Optional[aws_cdk.aws_ecs.ClusterProps] = None,
         container_definition_props: typing.Any = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
         event_bus_environment_variable_name: typing.Optional[builtins.str] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
         existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         fargate_service_props: typing.Any = None,
         fargate_task_definition_props: typing.Any = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
         :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct. Default: - None
@@ -322,40 +296,6 @@ class FargateToEventbridgeProps:
             event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
-        if __debug__:
-            def stub(
-                *,
-                public_api: builtins.bool,
-                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
-                container_definition_props: typing.Any = None,
-                ecr_image_version: typing.Optional[builtins.str] = None,
-                ecr_repository_arn: typing.Optional[builtins.str] = None,
-                event_bus_environment_variable_name: typing.Optional[builtins.str] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                fargate_service_props: typing.Any = None,
-                fargate_task_definition_props: typing.Any = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
-            check_type(argname="argument cluster_props", value=cluster_props, expected_type=type_hints["cluster_props"])
-            check_type(argname="argument container_definition_props", value=container_definition_props, expected_type=type_hints["container_definition_props"])
-            check_type(argname="argument ecr_image_version", value=ecr_image_version, expected_type=type_hints["ecr_image_version"])
-            check_type(argname="argument ecr_repository_arn", value=ecr_repository_arn, expected_type=type_hints["ecr_repository_arn"])
-            check_type(argname="argument event_bus_environment_variable_name", value=event_bus_environment_variable_name, expected_type=type_hints["event_bus_environment_variable_name"])
-            check_type(argname="argument event_bus_props", value=event_bus_props, expected_type=type_hints["event_bus_props"])
-            check_type(argname="argument existing_container_definition_object", value=existing_container_definition_object, expected_type=type_hints["existing_container_definition_object"])
-            check_type(argname="argument existing_event_bus_interface", value=existing_event_bus_interface, expected_type=type_hints["existing_event_bus_interface"])
-            check_type(argname="argument existing_fargate_service_object", value=existing_fargate_service_object, expected_type=type_hints["existing_fargate_service_object"])
-            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
-            check_type(argname="argument fargate_service_props", value=fargate_service_props, expected_type=type_hints["fargate_service_props"])
-            check_type(argname="argument fargate_task_definition_props", value=fargate_task_definition_props, expected_type=type_hints["fargate_task_definition_props"])
-            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "public_api": public_api,
         }
